@@ -13,6 +13,16 @@ var groupByOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::- - {foo: 1, bar: 10}\n  - {foo: 1, bar: 1}\n- - {foo: 3, bar: 100}\n",
 		},
 	},
+	{
+		description: "Group splat",
+		skipDoc:     true,
+		document:    `[{foo: 1, bar: 10}, {foo: 3, bar: 100}, {foo: 1, bar: 1}]`,
+		expression:  `group_by(.foo)[]`,
+		expected: []string{
+			"D0, P[0], (!!seq)::- {foo: 1, bar: 10}\n- {foo: 1, bar: 1}\n",
+			"D0, P[1], (!!seq)::- {foo: 3, bar: 100}\n",
+		},
+	},
 	{
 		description: "Group by field, with nulls",
 		document:    `[{cat: dog}, {foo: 1, bar: 10}, {foo: 3, bar: 100}, {no: foo for you}, {foo: 1, bar: 1}]`,
