@@ -47,10 +47,10 @@ var styleOperatorScenarios = []expressionScenario{
 	},
 	{
 		skipDoc:    true,
-		document:   "bing: &foo frog\na:\n  c: cat\n  <<: [*foo]",
+		document:   "bing: &foo {x: z}\na:\n  c: cat\n  <<: [*foo]",
 		expression: `(... | select(tag=="!!str")) style="single"`,
 		expected: []string{
-			"D0, P[], (!!map)::'bing': &foo 'frog'\n'a':\n    'c': 'cat'\n    !!merge <<: [*foo]\n",
+			"D0, P[], (!!map)::'bing': &foo {'x': 'z'}\n'a':\n    'c': 'cat'\n    !!merge <<: [*foo]\n",
 		},
 	},
 	{
